@@ -1095,6 +1095,12 @@ void cb_mainview_close (GtkObject *, Application *app) {
     debugLog () << "close" << endl;
 }
 
+static bool testFullscreenPlaylist (Application *app) {
+    Control *ctr = CONTROL(app);
+    return ((ctr->process () != ctr->mplayer || !ctr->process ()->hasXv ()) &&
+            app->fullscreen);
+}
+
 gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
     switch (e->keyval) {
         case GDK_F6: //HILDON_HARDKEY_FULLSCREEN:
@@ -1126,20 +1132,22 @@ gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app) {
                 CONTROL(app)->process ()->seek (200, false); // 20s
             break;
         case GDK_Return: // HILDON_HARDKEY_SELECT
-            if (app->fullscreen)
+            if (testFullscreenPlaylist (app))
                 rowSelected (app);
             break;
         case GDK_Up:
-            if (app->fullscreen)
+            if (testFullscreenPlaylist (app))
                 previousSelected (app);
             break;
         case GDK_Down:
-            if (app->fullscreen)
+            if (testFullscreenPlaylist (app))
                 nextSelected (app);
             break;
         case GDK_Escape:
-            if (app->fullscreen)
+            if (testFullscreenPlaylist (app))
                 VIEWAREA(app)->controlsVisible (app, true);
+            else
+                return true;
             break;
         default:
             KMPlayer::debugLog () << "Keypress " << e->keyval << KMPlayer::endl;
