@@ -844,19 +844,20 @@ size_t curlHeaderLine( void *ptr, size_t size, size_t nmemb, void *stream) {
             char *p = strchr ((char *)ptr + 5, ' ');
             if (p) {
                 int rc = strtol (p +1, NULL, 10);
-                if (rc >= 300)
-                    job->redirected = true;
-                else if (rc >= 400)
+                if (rc >= 400)
                     job->error_code = rc;
+                else if (rc >= 300)
+                    job->redirected = true;
             }
         } else if (job->redirected && !strncasecmp ((char *)ptr, "location:", 9)) {
-            String nuri ((char *)ptr+9);
+            String nuri ((char *) ptr + 9, size * nmemb - 9);
             job->m_receiver->redirected (job, nuri.stripWhiteSpace ());
             job->redirected = false;
         } else if (!strncasecmp ((char *)ptr, "content-length:", 15)) {
             job->content_length = strtol ((char *)ptr + 15, NULL, 10);
         } else if (!strncasecmp ((char *)ptr, "content-type:", 13)) {
-            job->content_type = String ((char *)ptr + 13).stripWhiteSpace ();
+            job->content_type = String (
+                    (char *)ptr + 13, size * nmemb - 13).stripWhiteSpace ();
         }
     }
     return size * nmemb;
@@ -941,7 +942,7 @@ KMPLAYER_NO_EXPORT void CurlGetJob::kill (bool q) {
 }
 
 KMPLAYER_NO_EXPORT bool CurlGetJob::error () {
-    return false;
+    return error_code;
 }
 
 //-----------------------------------------------------------------------------
@@ -962,11 +963,13 @@ KMPLAYER_NO_CDTOR_EXPORT GConf::~GConf () {
 }
 
 KMPLAYER_NO_EXPORT int GConf::readNumEntry (const String & key, int def) {
-    GError * err;
-    int val = gconf_client_get_int (client, (const char *) key, &err);
-    bool has_err = !!err;
-    g_error_free (err);
-    return has_err ? def : val;
+    GConfValue *val = gconf_client_get (client, (const char *) key, 0L);
+    if (val) {
+        int i = gconf_value_get_int (val);
+        gconf_value_free (val);
+        return i;
+    }
+    return def;
 }
 
 KMPLAYER_NO_EXPORT double GConf::readNumEntry (const String & key, double def) {
