@@ -1846,7 +1846,7 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
             XKeyEvent keyevent = event->xkey;
             if (a->fullscreen &&
                     XKeycodeToKeysym (event->xany.display, keyevent.keycode, 0) == XK_F4)
-                return GDK_FILTER_CONTINUE; //GDK_FILTER_REMOVE;
+                return GDK_FILTER_REMOVE; //GDK_FILTER_CONTINUE;
             Window v = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoWindow()));
             Window i = GDK_DRAWABLE_XID(GDK_DRAWABLE(view_area->videoInputWindow()));
             int depth = event->xany.window == i
@@ -1927,6 +1927,11 @@ GdkFilterReturn videoWidgetFilter (GdkXEvent *xe, GdkEvent *e, Application *a) {
                     XSendEvent (event->xany.display, evt.window, False,
                             evt_mask, (XEvent *) &evt);
                     XFlush (event->xany.display);
+                    if (event->xany.type == ButtonRelease) {
+                        XSetInputFocus (event->xany.display, evt.window,
+                                RevertToParent, CurrentTime);
+                        XFlush (event->xany.display);
+                    }
                     return GDK_FILTER_REMOVE;
                 }
             }
